@@ -15,6 +15,7 @@ from datetime import datetime
 from os import getenv, makedirs, mkdir, path, remove, removedirs, rmdir
 from os.path import expanduser
 from threading import Lock, Thread
+from typing import Dict, Union
 
 from .auth_keypair import AuthByKeyPair
 from .auth_usrpwdmfa import AuthByUsrPwdMfa
@@ -27,9 +28,22 @@ from .constants import (
     PARAMETER_CLIENT_REQUEST_MFA_TOKEN,
     PARAMETER_CLIENT_STORE_TEMPORARY_CREDENTIAL,
 )
-from .description import COMPILER, IMPLEMENTATION, OPERATING_SYSTEM, PLATFORM, PYTHON_VERSION
+from .description import (
+    COMPILER,
+    IMPLEMENTATION,
+    OPERATING_SYSTEM,
+    PLATFORM,
+    PYTHON_VERSION,
+)
 from .errorcode import ER_FAILED_TO_CONNECT_TO_DB
-from .errors import BadGatewayError, DatabaseError, Error, ForbiddenError, ProgrammingError, ServiceUnavailableError
+from .errors import (
+    BadGatewayError,
+    DatabaseError,
+    Error,
+    ForbiddenError,
+    ProgrammingError,
+    ServiceUnavailableError,
+)
 from .network import (
     ACCEPT_TYPE_APPLICATION_SNOWFLAKE,
     CONTENT_TYPE_APPLICATION_JSON,
@@ -44,22 +58,23 @@ from .version import VERSION
 logger = logging.getLogger(__name__)
 
 # Cache directory
-CACHE_ROOT_DIR = getenv('SF_TEMPORARY_CREDENTIAL_CACHE_DIR') or \
-                 expanduser("~") or tempfile.gettempdir()
+CACHE_ROOT_DIR = (
+    getenv("SF_TEMPORARY_CREDENTIAL_CACHE_DIR")
+    or expanduser("~")
+    or tempfile.gettempdir()
+)
 if IS_WINDOWS:
-    CACHE_DIR = path.join(CACHE_ROOT_DIR, 'AppData', 'Local', 'Snowflake',
-                          'Caches')
+    CACHE_DIR = path.join(CACHE_ROOT_DIR, "AppData", "Local", "Snowflake", "Caches")
 elif IS_MACOS:
-    CACHE_DIR = path.join(CACHE_ROOT_DIR, 'Library', 'Caches', 'Snowflake')
+    CACHE_DIR = path.join(CACHE_ROOT_DIR, "Library", "Caches", "Snowflake")
 else:
-    CACHE_DIR = path.join(CACHE_ROOT_DIR, '.cache', 'snowflake')
+    CACHE_DIR = path.join(CACHE_ROOT_DIR, ".cache", "snowflake")
 
 if not path.exists(CACHE_DIR):
     try:
         makedirs(CACHE_DIR, mode=0o700)
     except Exception as ex:
-        logger.debug('cannot create a cache directory: [%s], err=[%s]',
-                       CACHE_DIR, ex)
+        logger.debug("cannot create a cache directory: [%s], err=[%s]", CACHE_DIR, ex)
         CACHE_DIR = None
 logger.debug("cache directory: %s", CACHE_DIR)
 
@@ -70,8 +85,9 @@ TEMPORARY_CREDENTIAL_LOCK = Lock()
 
 # temporary credential cache file name
 TEMPORARY_CREDENTIAL_FILE = "temporary_credential.json"
-TEMPORARY_CREDENTIAL_FILE = path.join(
-    CACHE_DIR, TEMPORARY_CREDENTIAL_FILE) if CACHE_DIR else ""
+TEMPORARY_CREDENTIAL_FILE = (
+    path.join(CACHE_DIR, TEMPORARY_CREDENTIAL_FILE) if CACHE_DIR else ""
+)
 
 # temporary credential cache lock directory name
 TEMPORARY_CREDENTIAL_FILE_LOCK = TEMPORARY_CREDENTIAL_FILE + ".lck"
@@ -92,13 +108,18 @@ class Auth(object):
         self._rest = rest
 
     @staticmethod
-    def base_auth_data(user, account, application,
-                       internal_application_name,
-                       internal_application_version,
-                       ocsp_mode, login_timeout,
-                       network_timeout=None):
+    def base_auth_data(
+        user,
+        account,
+        application,
+        internal_application_name,
+        internal_application_version,
+        ocsp_mode,
+        login_timeout,
+        network_timeout=None,
+    ):
         return {
-            'data': {
+            "data": {
                 "CLIENT_APP_ID": internal_application_name,
                 "CLIENT_APP_VERSION": internal_application_version,
                 "SVN_REVISION": VERSION[3],
@@ -115,17 +136,27 @@ class Auth(object):
                     "TRACING": logger.getEffectiveLevel(),
                     "LOGIN_TIMEOUT": login_timeout,
                     "NETWORK_TIMEOUT": network_timeout,
-                }
+                },
             },
         }
 
-    def authenticate(self, auth_instance, account, user,
-                     database=None, schema=None,
-                     warehouse=None, role=None, passcode=None,
-                     passcode_in_password=False,
-                     mfa_callback=None, password_callback=None,
-                     session_parameters=None, timeout=120):
-        logger.debug('authenticate')
+    def authenticate(
+        self,
+        auth_instance,
+        account,
+        user,
+        database=None,
+        schema=None,
+        warehouse=None,
+        role=None,
+        passcode=None,
+        passcode_in_password=False,
+        mfa_callback=None,
+        password_callback=None,
+        session_parameters=None,
+        timeout=120,
+    ) -> Dict[str, Union[str, int, bool]]:
+        logger.debug("authenticate")
 
         if session_parameters is None:
             session_parameters = {}
@@ -137,12 +168,15 @@ class Auth(object):
             HTTP_HEADER_USER_AGENT: PYTHON_CONNECTOR_USER_AGENT,
         }
         if HTTP_HEADER_SERVICE_NAME in session_parameters:
-            headers[HTTP_HEADER_SERVICE_NAME] = \
-                session_parameters[HTTP_HEADER_SERVICE_NAME]
+            headers[HTTP_HEADER_SERVICE_NAME] = session_parameters[
+                HTTP_HEADER_SERVICE_NAME
+            ]
         url = "/session/v1/login-request"
 
         body_template = Auth.base_auth_data(
-            user, account, self._rest._connection.application,
+            user,
+            account,
+            self._rest._connection.application,
             self._rest._connection._internal_application_name,
             self._rest._connection._internal_application_version,
             self._rest._connection._ocsp_mode(),
@@ -152,13 +186,12 @@ class Auth(object):
 
         body = copy.deepcopy(body_template)
         # updating request body
-        logger.debug('assertion content: %s',
-                     auth_instance.assertion_content)
+        logger.debug("assertion content: %s", auth_instance.assertion_content)
         auth_instance.update_body(body)
 
         logger.debug(
-            'account=%s, user=%s, database=%s, schema=%s, '
-            'warehouse=%s, role=%s, request_id=%s',
+            "account=%s, user=%s, database=%s, schema=%s, "
+            "warehouse=%s, role=%s, request_id=%s",
             account,
             user,
             database,
@@ -167,130 +200,150 @@ class Auth(object):
             role,
             request_id,
         )
-        url_parameters = {'request_id': request_id}
+        url_parameters = {"request_id": request_id}
         if database is not None:
-            url_parameters['databaseName'] = database
+            url_parameters["databaseName"] = database
         if schema is not None:
-            url_parameters['schemaName'] = schema
+            url_parameters["schemaName"] = schema
         if warehouse is not None:
-            url_parameters['warehouse'] = warehouse
+            url_parameters["warehouse"] = warehouse
         if role is not None:
-            url_parameters['roleName'] = role
+            url_parameters["roleName"] = role
 
-        url = url + '?' + urlencode(url_parameters)
+        url = url + "?" + urlencode(url_parameters)
 
         # first auth request
         if passcode_in_password:
-            body['data']['EXT_AUTHN_DUO_METHOD'] = 'passcode'
+            body["data"]["EXT_AUTHN_DUO_METHOD"] = "passcode"
         elif passcode:
-            body['data']['EXT_AUTHN_DUO_METHOD'] = 'passcode'
-            body['data']['PASSCODE'] = passcode
+            body["data"]["EXT_AUTHN_DUO_METHOD"] = "passcode"
+            body["data"]["PASSCODE"] = passcode
 
         if session_parameters:
-            body['data']['SESSION_PARAMETERS'] = session_parameters
+            body["data"]["SESSION_PARAMETERS"] = session_parameters
 
         logger.debug(
             "body['data']: %s",
-            {k: v for (k, v) in body['data'].items() if k != 'PASSWORD'})
+            {k: v for (k, v) in body["data"].items() if k != "PASSWORD"},
+        )
 
         try:
             ret = self._rest._post_request(
-                url, headers, json.dumps(body),
+                url,
+                headers,
+                json.dumps(body),
                 timeout=self._rest._connection.login_timeout,
-                socket_timeout=self._rest._connection.login_timeout)
+                socket_timeout=self._rest._connection.login_timeout,
+            )
         except ForbiddenError as err:
             # HTTP 403
             raise err.__class__(
-                msg=("Failed to connect to DB. "
-                     "Verify the account name is correct: {host}:{port}. "
-                     "{message}").format(
-                    host=self._rest._host,
-                    port=self._rest._port,
-                    message=str(err)
+                msg=(
+                    "Failed to connect to DB. "
+                    "Verify the account name is correct: {host}:{port}. "
+                    "{message}"
+                ).format(
+                    host=self._rest._host, port=self._rest._port, message=str(err)
                 ),
                 errno=ER_FAILED_TO_CONNECT_TO_DB,
-                sqlstate=SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED)
+                sqlstate=SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED,
+            )
         except (ServiceUnavailableError, BadGatewayError) as err:
             # HTTP 502/504
             raise err.__class__(
-                msg=("Failed to connect to DB. "
-                     "Service is unavailable: {host}:{port}. "
-                     "{message}").format(
-                    host=self._rest._host,
-                    port=self._rest._port,
-                    message=str(err)
+                msg=(
+                    "Failed to connect to DB. "
+                    "Service is unavailable: {host}:{port}. "
+                    "{message}"
+                ).format(
+                    host=self._rest._host, port=self._rest._port, message=str(err)
                 ),
                 errno=ER_FAILED_TO_CONNECT_TO_DB,
-                sqlstate=SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED)
+                sqlstate=SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED,
+            )
 
         # waiting for MFA authentication
-        if ret['data'].get('nextAction') == 'EXT_AUTHN_DUO_ALL':
-            body['inFlightCtx'] = ret['data']['inFlightCtx']
-            body['data']['EXT_AUTHN_DUO_METHOD'] = 'push'
-            self.ret = {'message': "Timeout", 'data': {}}
+        if ret["data"].get("nextAction") == "EXT_AUTHN_DUO_ALL":
+            body["inFlightCtx"] = ret["data"]["inFlightCtx"]
+            body["data"]["EXT_AUTHN_DUO_METHOD"] = "push"
+            self.ret = {"message": "Timeout", "data": {}}
 
             def post_request_wrapper(self, url, headers, body):
                 # get the MFA response
                 self.ret = self._rest._post_request(
-                    url, headers, body,
-                    timeout=self._rest._connection.login_timeout)
+                    url, headers, body, timeout=self._rest._connection.login_timeout
+                )
 
             # send new request to wait until MFA is approved
-            t = Thread(target=post_request_wrapper,
-                       args=[self, url, headers, json.dumps(body)])
+            t = Thread(
+                target=post_request_wrapper, args=[self, url, headers, json.dumps(body)]
+            )
             t.daemon = True
             t.start()
             if callable(mfa_callback):
                 c = mfa_callback()
-                while not self.ret or self.ret.get('message') == 'Timeout':
+                while not self.ret or self.ret.get("message") == "Timeout":
                     next(c)
             else:
                 t.join(timeout=timeout)
 
             ret = self.ret
-            if ret and ret['data'].get('nextAction') == 'EXT_AUTHN_SUCCESS':
+            if ret and ret["data"].get("nextAction") == "EXT_AUTHN_SUCCESS":
                 body = copy.deepcopy(body_template)
-                body['inFlightCtx'] = ret['data']['inFlightCtx']
+                body["inFlightCtx"] = ret["data"]["inFlightCtx"]
                 # final request to get tokens
                 ret = self._rest._post_request(
-                    url, headers, json.dumps(body),
+                    url,
+                    headers,
+                    json.dumps(body),
                     timeout=self._rest._connection.login_timeout,
-                    socket_timeout=self._rest._connection.login_timeout)
-            elif not ret or not ret['data'].get('token'):
+                    socket_timeout=self._rest._connection.login_timeout,
+                )
+            elif not ret or not ret["data"].get("token"):
                 # not token is returned.
                 Error.errorhandler_wrapper(
-                    self._rest._connection, None, DatabaseError,
+                    self._rest._connection,
+                    None,
+                    DatabaseError,
                     {
-                        'msg': ("Failed to connect to DB. MFA "
-                                 "authentication failed: {"
-                                 "host}:{port}. {message}").format(
+                        "msg": (
+                            "Failed to connect to DB. MFA "
+                            "authentication failed: {"
+                            "host}:{port}. {message}"
+                        ).format(
                             host=self._rest._host,
                             port=self._rest._port,
-                            message=ret['message'],
+                            message=ret["message"],
                         ),
-                        'errno': ER_FAILED_TO_CONNECT_TO_DB,
-                        'sqlstate': SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED,
-                    })
+                        "errno": ER_FAILED_TO_CONNECT_TO_DB,
+                        "sqlstate": SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED,
+                    },
+                )
                 return session_parameters  # required for unit test
 
-        elif ret['data'].get('nextAction') == 'PWD_CHANGE':
+        elif ret["data"].get("nextAction") == "PWD_CHANGE":
             if callable(password_callback):
                 body = copy.deepcopy(body_template)
-                body['inFlightCtx'] = ret['data']['inFlightCtx']
-                body['data']["LOGIN_NAME"] = user
-                body['data']["PASSWORD"] = \
-                    auth_instance.password if hasattr(
-                        auth_instance, 'password') else None
-                body['data']['CHOSEN_NEW_PASSWORD'] = password_callback()
+                body["inFlightCtx"] = ret["data"]["inFlightCtx"]
+                body["data"]["LOGIN_NAME"] = user
+                body["data"]["PASSWORD"] = (
+                    auth_instance.password
+                    if hasattr(auth_instance, "password")
+                    else None
+                )
+                body["data"]["CHOSEN_NEW_PASSWORD"] = password_callback()
                 # New Password input
                 ret = self._rest._post_request(
-                    url, headers, json.dumps(body),
+                    url,
+                    headers,
+                    json.dumps(body),
                     timeout=self._rest._connection.login_timeout,
-                    socket_timeout=self._rest._connection.login_timeout)
+                    socket_timeout=self._rest._connection.login_timeout,
+                )
 
-        logger.debug('completed authentication')
-        if not ret['success']:
-            errno = ret.get('code', ER_FAILED_TO_CONNECT_TO_DB)
+        logger.debug("completed authentication")
+        if not ret["success"]:
+            errno = ret.get("code", ER_FAILED_TO_CONNECT_TO_DB)
             if errno == ID_TOKEN_INVALID_LOGIN_REQUEST_GS_CODE:
                 # clear stored id_token if failed to connect because of id_token
                 # raise an exception for reauth without id_token
@@ -298,9 +351,11 @@ class Auth(object):
                 delete_temporary_credential(self._rest._host, user, ID_TOKEN)
                 raise ReauthenticationRequest(
                     ProgrammingError(
-                        msg=ret['message'],
+                        msg=ret["message"],
                         errno=int(errno),
-                        sqlstate=SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED))
+                        sqlstate=SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED,
+                    )
+                )
 
             if type(auth_instance) is AuthByKeyPair:
                 logger.debug(
@@ -308,75 +363,93 @@ class Auth(object):
                     "Token expires at: %s. "
                     "Current Time: %s",
                     str(auth_instance._jwt_token_exp),
-                    str(datetime.utcnow())
+                    str(datetime.utcnow()),
                 )
             if type(auth_instance) is AuthByUsrPwdMfa:
                 delete_temporary_credential(self._rest._host, user, MFA_TOKEN)
             Error.errorhandler_wrapper(
-                self._rest._connection, None, DatabaseError,
+                self._rest._connection,
+                None,
+                DatabaseError,
                 {
-                    'msg': ("Failed to connect to DB: {host}:{port}. "
-                             "{message}").format(
+                    "msg": (
+                        "Failed to connect to DB: {host}:{port}. " "{message}"
+                    ).format(
                         host=self._rest._host,
                         port=self._rest._port,
-                        message=ret['message'],
+                        message=ret["message"],
                     ),
-                    'errno': ER_FAILED_TO_CONNECT_TO_DB,
-                    'sqlstate': SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED,
-                })
-        else:
-            logger.debug('token = %s',
-                         '******' if ret['data']['token'] is not None else
-                         'NULL')
-            logger.debug('master_token = %s',
-                         '******' if ret['data'][
-                                         'masterToken'] is not None else
-                         'NULL')
-            logger.debug('id_token = %s',
-                         '******' if ret['data'].get(
-                             'idToken') is not None else
-                         'NULL')
-            logger.debug('mfa_token = %s',
-                         '******' if ret['data'].get(
-                             'mfaToken') is not None else
-                         'NULL')
-            self._rest.update_tokens(
-                ret['data']['token'], ret['data']['masterToken'],
-                master_validity_in_seconds=ret['data'].get(
-                    'masterValidityInSeconds'),
-                id_token=ret['data'].get('idToken'),
-                mfa_token=ret['data'].get('mfaToken')
+                    "errno": ER_FAILED_TO_CONNECT_TO_DB,
+                    "sqlstate": SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED,
+                },
             )
-            self.write_temporary_credentials(self._rest._host, user, session_parameters, ret)
-            if 'sessionId' in ret['data']:
-                self._rest._connection._session_id = ret['data']['sessionId']
-            if 'sessionInfo' in ret['data']:
-                session_info = ret['data']['sessionInfo']
-                self._rest._connection._database = session_info.get('databaseName')
-                self._rest._connection._schema = session_info.get('schemaName')
-                self._rest._connection._warehouse = session_info.get('warehouseName')
-                self._rest._connection._role = session_info.get('roleName')
-            self._rest._connection._set_parameters(ret, session_parameters)
-
-        return session_parameters
+        else:
+            logger.debug(
+                "token = %s", "******" if ret["data"]["token"] is not None else "NULL"
+            )
+            logger.debug(
+                "master_token = %s",
+                "******" if ret["data"]["masterToken"] is not None else "NULL",
+            )
+            logger.debug(
+                "id_token = %s",
+                "******" if ret["data"].get("idToken") is not None else "NULL",
+            )
+            logger.debug(
+                "mfa_token = %s",
+                "******" if ret["data"].get("mfaToken") is not None else "NULL",
+            )
+            self._rest.update_tokens(
+                ret["data"]["token"],
+                ret["data"]["masterToken"],
+                master_validity_in_seconds=ret["data"].get("masterValidityInSeconds"),
+                id_token=ret["data"].get("idToken"),
+                mfa_token=ret["data"].get("mfaToken"),
+            )
+            self.write_temporary_credentials(
+                self._rest._host, user, session_parameters, ret
+            )
+            if "sessionId" in ret["data"]:
+                self._rest._connection._session_id = ret["data"]["sessionId"]
+            if "sessionInfo" in ret["data"]:
+                session_info = ret["data"]["sessionInfo"]
+                self._rest._connection._database = session_info.get("databaseName")
+                self._rest._connection._schema = session_info.get("schemaName")
+                self._rest._connection._warehouse = session_info.get("warehouseName")
+                self._rest._connection._role = session_info.get("roleName")
+            if "parameters" in ret["data"]:
+                session_parameters.update(
+                    {p["name"]: p["value"] for p in ret["data"]["parameters"]}
+                )
+            self._rest._connection._update_parameters(session_parameters)
+            return session_parameters
 
     def _read_temporary_credential(self, host, user, cred_type):
         cred = None
         if IS_MACOS or IS_WINDOWS:
             if not installed_keyring:
-                logger.debug("Dependency 'keyring' is not installed, cannot cache id token. You might experience "
-                             "multiple authentication pop ups while using ExternalBrowser Authenticator. To avoid "
-                             "this please install keyring module using the following command : pip install "
-                             "snowflake-connector-python[secure-local-storage]")
+                logger.debug(
+                    "Dependency 'keyring' is not installed, cannot cache id token. You might experience "
+                    "multiple authentication pop ups while using ExternalBrowser Authenticator. To avoid "
+                    "this please install keyring module using the following command : pip install "
+                    "snowflake-connector-python[secure-local-storage]"
+                )
                 return
             try:
-                cred = keyring.get_password(build_temporary_credential_name(host, user, cred_type), user.upper())
+                cred = keyring.get_password(
+                    build_temporary_credential_name(host, user, cred_type), user.upper()
+                )
             except keyring.errors.KeyringError as ke:
-                logger.error("Could not retrieve {} from secure storage : {}".format(cred_type, str(ke)))
+                logger.error(
+                    "Could not retrieve {} from secure storage : {}".format(
+                        cred_type, str(ke)
+                    )
+                )
         elif IS_LINUX:
             read_temporary_credential_file()
-            cred = TEMPORARY_CREDENTIAL.get(
-                    host.upper(), {}).get(build_temporary_credential_name(host, user, cred_type))
+            cred = TEMPORARY_CREDENTIAL.get(host.upper(), {}).get(
+                build_temporary_credential_name(host, user, cred_type)
+            )
         else:
             logger.debug("OS not supported for Local Secure Storage")
         return cred
@@ -386,35 +459,52 @@ class Auth(object):
             self._rest.id_token = self._read_temporary_credential(host, user, ID_TOKEN)
 
         if session_parameters.get(PARAMETER_CLIENT_REQUEST_MFA_TOKEN, False):
-            self._rest.mfa_token = self._read_temporary_credential(host, user, MFA_TOKEN)
+            self._rest.mfa_token = self._read_temporary_credential(
+                host, user, MFA_TOKEN
+            )
 
     def _write_temporary_credential(self, host, user, cred_type, cred):
         if not cred:
-            logger.debug("no credential is given when try to store temporary credential")
+            logger.debug(
+                "no credential is given when try to store temporary credential"
+            )
             return
         if IS_MACOS or IS_WINDOWS:
             if not installed_keyring:
-                logger.debug("Dependency 'keyring' is not installed, cannot cache id token. You might experience "
-                             "multiple authentication pop ups while using ExternalBrowser Authenticator. To avoid "
-                             "this please install keyring module using the following command : pip install "
-                             "snowflake-connector-python[secure-local-storage]")
+                logger.debug(
+                    "Dependency 'keyring' is not installed, cannot cache id token. You might experience "
+                    "multiple authentication pop ups while using ExternalBrowser Authenticator. To avoid "
+                    "this please install keyring module using the following command : pip install "
+                    "snowflake-connector-python[secure-local-storage]"
+                )
                 return
             try:
-                keyring.set_password(build_temporary_credential_name(host, user, cred_type), user.upper(), cred)
+                keyring.set_password(
+                    build_temporary_credential_name(host, user, cred_type),
+                    user.upper(),
+                    cred,
+                )
             except keyring.errors.KeyringError as ke:
                 logger.error("Could not store id_token to keyring, %s", str(ke))
         elif IS_LINUX:
-            write_temporary_credential_file(host, build_temporary_credential_name(host, user, cred_type), cred)
+            write_temporary_credential_file(
+                host, build_temporary_credential_name(host, user, cred_type), cred
+            )
         else:
             logger.debug("OS not supported for Local Secure Storage")
 
     def write_temporary_credentials(self, host, user, session_parameters, response):
         if self._rest._connection.consent_cache_id_token and session_parameters.get(
-                PARAMETER_CLIENT_STORE_TEMPORARY_CREDENTIAL, False):
-            self._write_temporary_credential(host, user, ID_TOKEN, response['data'].get('idToken'))
+            PARAMETER_CLIENT_STORE_TEMPORARY_CREDENTIAL, False
+        ):
+            self._write_temporary_credential(
+                host, user, ID_TOKEN, response["data"].get("idToken")
+            )
 
         if session_parameters.get(PARAMETER_CLIENT_REQUEST_MFA_TOKEN, False):
-            self._write_temporary_credential(host, user, MFA_TOKEN, response['data'].get('mfaToken'))
+            self._write_temporary_credential(
+                host, user, MFA_TOKEN, response["data"].get("mfaToken")
+            )
         return
 
 
@@ -427,16 +517,22 @@ def flush_temporary_credentials():
             break
         time.sleep(1)
     else:
-        logger.debug("The lock file still persists after the maximum wait time."
-                     "Will ignore it and write temporary credential file: %s",
-                     TEMPORARY_CREDENTIAL_FILE)
+        logger.debug(
+            "The lock file still persists after the maximum wait time."
+            "Will ignore it and write temporary credential file: %s",
+            TEMPORARY_CREDENTIAL_FILE,
+        )
     try:
-        with open(TEMPORARY_CREDENTIAL_FILE, 'w',
-                  encoding='utf-8', errors='ignore') as f:
+        with open(
+            TEMPORARY_CREDENTIAL_FILE, "w", encoding="utf-8", errors="ignore"
+        ) as f:
             json.dump(TEMPORARY_CREDENTIAL, f)
     except Exception as ex:
-        logger.debug("Failed to write a credential file: "
-                     "file=[%s], err=[%s]", TEMPORARY_CREDENTIAL_FILE, ex)
+        logger.debug(
+            "Failed to write a credential file: " "file=[%s], err=[%s]",
+            TEMPORARY_CREDENTIAL_FILE,
+            ex,
+        )
     finally:
         unlock_temporary_credential_file()
 
@@ -471,18 +567,24 @@ def read_temporary_credential_file():
                 break
             time.sleep(1)
         else:
-            logger.debug("The lock file still persists. Will ignore and "
-                           "write the temporary credential file: %s",
-                           TEMPORARY_CREDENTIAL_FILE)
+            logger.debug(
+                "The lock file still persists. Will ignore and "
+                "write the temporary credential file: %s",
+                TEMPORARY_CREDENTIAL_FILE,
+            )
         try:
-            with codecs.open(TEMPORARY_CREDENTIAL_FILE, 'r',
-                             encoding='utf-8', errors='ignore') as f:
+            with codecs.open(
+                TEMPORARY_CREDENTIAL_FILE, "r", encoding="utf-8", errors="ignore"
+            ) as f:
                 TEMPORARY_CREDENTIAL = json.load(f)
             return TEMPORARY_CREDENTIAL
         except Exception as ex:
-            logger.debug("Failed to read a credential file. The file may not"
-                         "exists: file=[%s], err=[%s]",
-                         TEMPORARY_CREDENTIAL_FILE, ex)
+            logger.debug(
+                "Failed to read a credential file. The file may not"
+                "exists: file=[%s], err=[%s]",
+                TEMPORARY_CREDENTIAL_FILE,
+                ex,
+            )
         finally:
             unlock_temporary_credential_file()
     return None
@@ -494,8 +596,10 @@ def lock_temporary_credential_file():
         mkdir(TEMPORARY_CREDENTIAL_FILE_LOCK)
         return True
     except OSError:
-        logger.debug("Temporary cache file lock already exists. Other "
-                     "process may be updating the temporary ")
+        logger.debug(
+            "Temporary cache file lock already exists. Other "
+            "process may be updating the temporary "
+        )
         return False
 
 
@@ -512,7 +616,9 @@ def unlock_temporary_credential_file():
 def delete_temporary_credential(host, user, cred_type):
     if (IS_MACOS or IS_WINDOWS) and installed_keyring:
         try:
-            keyring.delete_password(build_temporary_credential_name(host, user, cred_type), user.upper())
+            keyring.delete_password(
+                build_temporary_credential_name(host, user, cred_type), user.upper()
+            )
         except Exception as ex:
             logger.error("Failed to delete credential in the keyring: err=[%s]", ex)
     elif IS_LINUX:
@@ -543,8 +649,11 @@ def delete_temporary_credential_file():
     try:
         remove(TEMPORARY_CREDENTIAL_FILE)
     except Exception as ex:
-        logger.debug("Failed to delete a credential file: "
-                     "file=[%s], err=[%s]", TEMPORARY_CREDENTIAL_FILE, ex)
+        logger.debug(
+            "Failed to delete a credential file: " "file=[%s], err=[%s]",
+            TEMPORARY_CREDENTIAL_FILE,
+            ex,
+        )
     try:
         removedirs(TEMPORARY_CREDENTIAL_FILE_LOCK)
     except Exception as ex:
@@ -553,7 +662,5 @@ def delete_temporary_credential_file():
 
 def build_temporary_credential_name(host, user, cred_type):
     return "{host}:{user}:{driver}:{cred}".format(
-            host=host.upper(),
-            user=user.upper(),
-            driver=KEYRING_DRIVER_NAME,
-            cred=cred_type)
+        host=host.upper(), user=user.upper(), driver=KEYRING_DRIVER_NAME, cred=cred_type
+    )
