@@ -32,11 +32,12 @@ logger = getLogger(__name__)
 Encryption Material
 """
 SnowflakeFileEncryptionMaterial = namedtuple(
-    "SnowflakeS3FileEncryptionMaterial", [
+    "SnowflakeS3FileEncryptionMaterial",
+    [
         "query_stage_master_key",  # query stage master key
         "query_id",  # query id
-        "smk_id"  # SMK id
-    ]
+        "smk_id",  # SMK id
+    ],
 )
 
 
@@ -45,14 +46,13 @@ class NeedRenewTokenError(Exception):
 
 
 class SnowflakeRemoteStorageUtil(object):
-
     @staticmethod
     def get_for_storage_type(_type):
-        if _type == 'S3':
+        if _type == "S3":
             return SnowflakeS3Util
-        elif _type == 'AZURE':
+        elif _type == "AZURE":
             return SnowflakeAzureUtil
-        elif _type == 'GCS':
+        elif _type == "GCS":
             return SnowflakeGCSUtil
         else:
             return None
@@ -60,60 +60,67 @@ class SnowflakeRemoteStorageUtil(object):
     @staticmethod
     def create_client(stage_info, use_accelerate_endpoint=False):
         util_class = SnowflakeRemoteStorageUtil.get_for_storage_type(
-            stage_info['locationType'])
+            stage_info["locationType"]
+        )
         return util_class.create_client(
-            stage_info,
-            use_accelerate_endpoint=use_accelerate_endpoint)
+            stage_info, use_accelerate_endpoint=use_accelerate_endpoint
+        )
 
     @staticmethod
-    def upload_one_file(meta: 'SnowflakeFileMeta') -> None:
+    def upload_one_file(meta: "SnowflakeFileMeta") -> None:
         """Uploads a file to S3."""
         encryption_metadata = None
 
         if meta.encryption_material is not None:
             if meta.src_stream is None:
-                (encryption_metadata,
-                 data_file) = SnowflakeEncryptionUtil.encrypt_file(
+                (encryption_metadata, data_file) = SnowflakeEncryptionUtil.encrypt_file(
                     meta.encryption_material,
-                    meta.real_src_file_name, tmp_dir=meta.tmp_dir)
-                logger.debug(f'encrypted data file={data_file}, size={os.path.getsize(data_file)}')
+                    meta.real_src_file_name,
+                    tmp_dir=meta.tmp_dir,
+                )
+                logger.debug(
+                    f"encrypted data file={data_file}, size={os.path.getsize(data_file)}"
+                )
             else:
                 encrypted_stream = BytesIO()
                 src_stream = meta.real_src_stream or meta.src_stream
                 src_stream.seek(0)
                 encryption_metadata = SnowflakeEncryptionUtil.encrypt_stream(
-                    meta.encryption_material,
-                    src_stream,
-                    encrypted_stream
+                    meta.encryption_material, src_stream, encrypted_stream
                 )
                 src_stream.seek(0)
-                logger.debug(f'encrypted data stream size={encrypted_stream.seek(0, os.SEEK_END)}')
+                logger.debug(
+                    f"encrypted data stream size={encrypted_stream.seek(0, os.SEEK_END)}"
+                )
                 encrypted_stream.seek(0)
                 if meta.real_src_stream is not None:
                     meta.real_src_stream.close()
                 meta.real_src_stream = encrypted_stream
                 data_file = meta.real_src_file_name
         else:
-            logger.debug('not encrypted data file')
+            logger.debug("not encrypted data file")
             data_file = meta.real_src_file_name
 
         util_class = SnowflakeRemoteStorageUtil.get_for_storage_type(
-            meta.stage_info['locationType'])
+            meta.client_meta.stage_info["locationType"]
+        )
 
-        logger.debug(f"putting a file: {meta.stage_info['location']}, {meta.dst_file_name}")
+        logger.debug(
+            f"putting a file: {meta.client_meta.stage_info['location']}, {meta.dst_file_name}"
+        )
 
         max_concurrency = meta.parallel
         last_err = None
         max_retry = DEFAULT_MAX_RETRY
         for retry in range(max_retry):
             if not meta.overwrite:
-                file_header = util_class.get_file_header(
-                    meta, meta.dst_file_name)
+                file_header = util_class.get_file_header(meta, meta.dst_file_name)
 
-                if file_header and \
-                        meta.result_status == ResultStatus.UPLOADED:
-                    logger.debug(f'file already exists location="{meta.stage_info["location"]}", '
-                                 f'file_name="{meta.dst_file_name}"')
+                if file_header and meta.result_status == ResultStatus.UPLOADED:
+                    logger.debug(
+                        f'file already exists location="{meta.client_meta.stage_info["location"]}", '
+                        f'file_name="{meta.dst_file_name}"'
+                    )
                     meta.dst_file_size = 0
                     meta.result_status = ResultStatus.SKIPPED
                     return
@@ -124,7 +131,7 @@ class SnowflakeRemoteStorageUtil(object):
                     meta,
                     encryption_metadata,
                     max_concurrency,
-                    multipart_threshold=meta.multipart_threshold
+                    multipart_threshold=meta.multipart_threshold,
                 )
 
             if meta.result_status == ResultStatus.UPLOADED:
@@ -135,22 +142,24 @@ class SnowflakeRemoteStorageUtil(object):
                 return
             elif meta.result_status == ResultStatus.NEED_RETRY:
                 last_err = meta.last_error
-                logger.debug(f'Failed to upload a file: {data_file}, err: {last_err}. Retrying with '
-                             f'max concurrency: {max_concurrency}')
+                logger.debug(
+                    f"Failed to upload a file: {data_file}, err: {last_err}. Retrying with "
+                    f"max concurrency: {max_concurrency}"
+                )
                 if not meta.no_sleeping_time:
                     sleeping_time = min(2 ** retry, 16)
                     logger.debug(f"sleeping {sleeping_time}")
                     time.sleep(sleeping_time)
             elif meta.result_status == ResultStatus.NEED_RETRY_WITH_LOWER_CONCURRENCY:
                 last_err = meta.last_error
-                max_concurrency = meta.parallel - int(
-                    retry * meta.parallel / max_retry)
+                max_concurrency = meta.parallel - int(retry * meta.parallel / max_retry)
                 max_concurrency = max(DEFAULT_CONCURRENCY, max_concurrency)
                 meta.last_max_concurrency = max_concurrency
 
                 logger.debug(
-                    f'Failed to upload a file: {data_file}, err: {last_err}. Retrying with '
-                    f'max concurrency: {max_concurrency}')
+                    f"Failed to upload a file: {data_file}, err: {last_err}. Retrying with "
+                    f"max concurrency: {max_concurrency}"
+                )
                 if meta.no_sleeping_time is None:
                     sleeping_time = min(2 ** retry, 16)
                     logger.debug(f"sleeping: {sleeping_time}")
@@ -163,33 +172,38 @@ class SnowflakeRemoteStorageUtil(object):
                 raise Exception(msg)
 
     @staticmethod
-    def download_one_file(meta: 'SnowflakeFileMeta') -> None:
+    def download_one_file(meta: "SnowflakeFileMeta") -> None:
         """Downloads a file from S3."""
-        full_dst_file_name = os.path.join(meta.local_location, os.path.basename(meta.dst_file_name))
+        full_dst_file_name = os.path.join(
+            meta.local_location, os.path.basename(meta.dst_file_name)
+        )
         full_dst_file_name = os.path.realpath(full_dst_file_name)
         # TODO: validate full_dst_file_name is under the writable directory
         base_dir = os.path.dirname(full_dst_file_name)
         if not os.path.exists(base_dir):
             os.makedirs(base_dir)
 
-        util_class = SnowflakeRemoteStorageUtil.get_for_storage_type(meta.stage_info['locationType'])
+        util_class = SnowflakeRemoteStorageUtil.get_for_storage_type(
+            meta.client_meta.stage_info["locationType"]
+        )
         file_header = util_class.get_file_header(meta, meta.src_file_name)
 
         if file_header:
             meta.src_file_size = file_header.content_length
 
-        full_dst_file_name = os.path.join(meta.local_location, os.path.basename(meta.dst_file_name))
+        full_dst_file_name = os.path.join(
+            meta.local_location, os.path.basename(meta.dst_file_name)
+        )
         full_dst_file_name = os.path.realpath(full_dst_file_name)
 
         max_concurrency = meta.parallel
         last_err = None
         max_retry = DEFAULT_MAX_RETRY
         for retry in range(max_retry):
-            util_class._native_download_file(meta, full_dst_file_name,
-                                             max_concurrency)
+            util_class._native_download_file(meta, full_dst_file_name, max_concurrency)
             if meta.result_status == ResultStatus.DOWNLOADED:
                 if meta.encryption_material is not None:
-                    logger.debug(f'encrypted data file={full_dst_file_name}')
+                    logger.debug(f"encrypted data file={full_dst_file_name}")
 
                     # For storage utils that do not have the privilege of
                     # getting the metadata early, both object and metadata
@@ -200,16 +214,20 @@ class SnowflakeRemoteStorageUtil(object):
                     # One example of this is the utils that use presigned url
                     # for upload/download and not the storage client library.
                     if meta.presigned_url is not None:
-                        file_header = util_class.get_file_header(meta, meta.src_file_name)
+                        file_header = util_class.get_file_header(
+                            meta, meta.src_file_name
+                        )
 
                     tmp_dst_file_name = SnowflakeEncryptionUtil.decrypt_file(
                         file_header.encryption_metadata,
                         meta.encryption_material,
-                        full_dst_file_name, tmp_dir=meta.tmp_dir)
+                        full_dst_file_name,
+                        tmp_dir=meta.tmp_dir,
+                    )
                     shutil.copyfile(tmp_dst_file_name, full_dst_file_name)
                     os.unlink(tmp_dst_file_name)
                 else:
-                    logger.debug(f'not encrypted data file={full_dst_file_name}')
+                    logger.debug(f"not encrypted data file={full_dst_file_name}")
 
                 stat_info = os.stat(full_dst_file_name)
                 meta.dst_file_size = stat_info.st_size
@@ -223,8 +241,10 @@ class SnowflakeRemoteStorageUtil(object):
                 max_concurrency = max(DEFAULT_CONCURRENCY, max_concurrency)
                 meta.last_max_concurrency = max_concurrency
                 last_err = meta.last_error
-                logger.debug(f'Failed to download a file: {full_dst_file_name}, err: {last_err}. Retrying with '
-                             f'max concurrency: {max_concurrency}')
+                logger.debug(
+                    f"Failed to download a file: {full_dst_file_name}, err: {last_err}. Retrying with "
+                    f"max concurrency: {max_concurrency}"
+                )
                 if not meta.no_sleeping_time:
                     sleeping_time = min(2 ** retry, 16)
                     logger.debug("sleeping: %s", sleeping_time)
@@ -232,8 +252,9 @@ class SnowflakeRemoteStorageUtil(object):
             elif meta.result_status == ResultStatus.NEED_RETRY:
                 last_err = meta.last_error
                 logger.debug(
-                    f'Failed to download a file: {full_dst_file_name}, err: {last_err}. Retrying with '
-                    f'max concurrency: {max_concurrency}')
+                    f"Failed to download a file: {full_dst_file_name}, err: {last_err}. Retrying with "
+                    f"max concurrency: {max_concurrency}"
+                )
                 if not meta.no_sleeping_time:
                     sleeping_time = min(2 ** retry, 16)
                     logger.debug(f"sleeping: {sleeping_time}")
@@ -246,9 +267,11 @@ class SnowflakeRemoteStorageUtil(object):
                 raise Exception(msg)
 
     @staticmethod
-    def upload_one_file_with_retry(meta: 'SnowflakeFileMeta') -> None:
+    def upload_one_file_with_retry(meta: "SnowflakeFileMeta") -> None:
         """Uploads one file with retry."""
-        util_class = SnowflakeRemoteStorageUtil.get_for_storage_type(meta.stage_info['locationType'])
+        util_class = SnowflakeRemoteStorageUtil.get_for_storage_type(
+            meta.client_meta.stage_info["locationType"]
+        )
         for _ in range(10):
             # retry
             SnowflakeRemoteStorageUtil.upload_one_file(meta)
@@ -257,12 +280,12 @@ class SnowflakeRemoteStorageUtil(object):
                     util_class.get_file_header(meta, meta.dst_file_name)
                     if meta.result_status == ResultStatus.NOT_FOUND_FILE:
                         time.sleep(1)  # wait 1 second
-                        logger.debug('not found. double checking...')
+                        logger.debug("not found. double checking...")
                         continue
                     break
                 else:
                     # not found. retry with the outer loop
-                    logger.debug('not found. gave up. re-uploading...')
+                    logger.debug("not found. gave up. re-uploading...")
                     continue
             break
         else:
